import board
import busio
import time
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode
import adafruit_vl53l0x
import json

# Load configuration from file
def load_config():
    try:
        with open("config.json", "r") as f:
            return json.load(f)
    except Exception as e:
        print("Error loading config file:", e)
        return {}

config = load_config()

# Initialize I2C and sensor
i2c = busio.I2C(board.SCL1, board.SDA1, frequency=400000)
tof = adafruit_vl53l0x.VL53L0X(i2c)

# Initialize keyboard HID
keyboard = Keyboard(usb_hid.devices)

# Define proximity range from config
RANGE_MIN = config.get("range_min", 30)
RANGE_MAX = config.get("range_max", 100)

# Define keycode from config (default to SPACE)
KEY = getattr(Keycode, config.get("key", "SPACE"))

while True:
    try:
        # Read distance in mm
        proximity = tof.range
        print(f"Proximity: {proximity} mm")

        # Check if within the defined range
        if RANGE_MIN <= proximity <= RANGE_MAX:
            keyboard.press(KEY)
            time.sleep(0.1)
            keyboard.release(KEY)
            print(f"{config.get('key', 'SPACE')} key pressed")

        # Delay before next check
        time.sleep(1)

    except OSError as e:
        print("Sensor error:", e)
